# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2020.06.25
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import agilicus_api
from agilicus_api.api.messages_api import MessagesApi  # noqa: E501
from agilicus_api.rest import ApiException


class TestMessagesApi(unittest.TestCase):
    """MessagesApi unit test stubs"""

    def setUp(self):
        self.api = agilicus_api.api.messages_api.MessagesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_message(self):
        """Test case for create_message

        Create a message (to a user)  # noqa: E501
        """
        pass

    def test_create_message_user(self):
        """Test case for create_message_user

        create a user with messaging endpoints  # noqa: E501
        """
        pass

    def test_list_message_users(self):
        """Test case for list_message_users

        List all users  # noqa: E501
        """
        pass

    def test_replace_message_user(self):
        """Test case for replace_message_user

        update a user with messaging endpoints  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
